"""
Plots of how work time was spent.

Requires pychart.
"""

# Copyright 2008, Markus Demleitner.  This file is under the GPL,
# see COPYING for details.

from datetime import date
import sys

from pychart import (area, pie_plot, fill_style, color, bar_plot, 
	category_coord, axis, canvas)

from pftf import due
from pftf import settings
from pftf import times


def makeCanvas(opts):
	"""returns a pychart canvas as specified in opts (cf. commandline).
	"""
	if opts.outputName=='-':
		return canvas.init(format=settings.get("plot", "format"))
	else:
		return canvas.init(fname=opts.outputName.encode("utf-8"), 
			format=settings.get("plot", "format"))


def getColorForLabel(label):
	col = settings.get("classCols", label)
	return fill_style.Plain(bgcolor=getattr(color, col, color.white))


def makeDayData(times):
	pass


def makeDistPieGraph(times):
	ar = area.T(size=(settings.get("plot", "width"), 
		settings.get("plot", "height")+settings.get("plot", "pieRadius")),
		legend=None, y_grid_style=None)
	dist = times.getWorkTimeDist()
	data = [("%s (%.0f%%)"%(label, dist[label]*100), dist[label], label)
		for label in settings.get("wClasses") if label in dist]
	fillStyles = [getColorForLabel(label) for _, _, label in data]
	ar.add_plot(pie_plot.T(data=data, arc_offsets=[0,0,0],
		fill_styles=fillStyles,
		label_offset=10, data_col=1, radius=settings.get("plot", "pieRadius"), 
		center=(settings.get("plot", "width")-
			settings.get("plot", "pieRadius")*1.5, settings.get("plot", "height")-
			settings.get("plot", "pieRadius")*0.25)))
	ar.draw()

def makeMonthBarGraph(times):
	globalDist = times.getWorkTimeDist()
	classesPresent = [label for label in settings.get("wClasses") 
		if label in globalDist]
	data = [(str(day.day),)+tuple(dist.get(label, 0) 
			for label in classesPresent)
		for day, dist in ((day, times.getForDay(day).getWorkTimes())
			for day in times.iterdays())]
	ar = area.T(size=(settings.get("plot", "width"), 
		settings.get("plot", "height")), 
		x_coord=category_coord.T(data, 0),
		y_axis=axis.Y(label="time spent [s]"), 
		x_axis=axis.X(label="date", format="/a90{}%s", tic_len=0,
			tic_label_offset=(0, -5)))
	barWidth = (settings.get("plot", "width")-settings.get("plot", "width")/6
		)/(len(data)+2)
	lastPlot = bar_plot.T(data=data, label=classesPresent[0],
		fill_style=getColorForLabel(classesPresent[0]), width=barWidth)
	ar.add_plot(lastPlot)
	for index, label in enumerate(classesPresent[1:]):
		lastPlot = bar_plot.T(data=data, hcol=index+2, label=label,
			fill_style=getColorForLabel(label), stack_on=lastPlot, width=barWidth)
		ar.add_plot(lastPlot)
	ar.draw()


def makeMonthGraph(opts):
	"""generates a graphics for the work given in the Times object times,
	where the plot is laid out such that it looks ok for a month.
	"""
	canvas = makeCanvas(opts)
	tForMonth = times.Times.forMonth(opts)
	makeMonthBarGraph(tForMonth)
	makeDistPieGraph(tForMonth)
	lineY = settings.get("plot", "height")-10
	canvas.show(10, lineY, "/b/17Work in %d-%02d: %.1f hours"%(
		opts.year, opts.month, tForMonth.getWorkTime()))
	canvas.show(10, lineY-20, 
		"/17Due was %.1f"%due.getHoursForMonth(opts.month, opts.year))

	canvas.close()

def printColors(opts):
	for attName in dir(color):
		if isinstance(getattr(color, attName), color.T):
			print attName
