"""
Tests for archive filing and inclusion.
"""

import testhelpers

from pftf import commandline
from pftf import timefile


testData = """2008-09-29T09:45:00	Admin
2008-09-29T17:45:00
2008-10-02T08:00:00	Dev
2008-10-01	Vac
2008-10-02T16:00:00
"""

class Anything(object):
	pass


class WithTestDataTest(testhelpers.CleanSlateTest):
	def setUp(self):
		testhelpers.CleanSlateTest.setUp(self)
		f = timefile.TimeFile().getAppendingFile()
		f.write(testData)
		f.close()


class ArchivingTest(WithTestDataTest):
	"""tests for correct splitting up of a pining file.
	"""
	def testArchive(self):
		opts = Anything()
		opts.year, opts.month, opts.day = 2008, 10, 12
		commandline.archive(opts)
		newPining = timefile.TimeFile().read()
		newPined = timefile.ArchiveFile().read()
		self.assertEqual(newPining, "2008-10-02T08:00:00\tDev\n2008-10-01\tVac"
			"\n2008-10-02T16:00:00\n")
		self.assertEqual(newPined, 
			"2008-09-29T09:45:00\tAdmin\n2008-09-29T17:45:00\n")


class ArchiveUseTest(WithTestDataTest):
	def testArchiveUse(self):
		opts = Anything()
		opts.year, opts.month, opts.day = 2008, 10, 1
		commandline.archive(opts)
		opts.withArchive = False
		t = commandline.getTimesForWeek(opts)
		self.assertEqual(t.getWorkTime(), 16)
		opts.withArchive = True
		t = commandline.getTimesForWeek(opts)
		self.assertEqual(t.getWorkTime(), 24)


if __name__=="__main__":
	testhelpers.main(ArchivingTest)
