"""
Tests for the configuration infrastructure.
"""

import unittest

from pftf import fancyconfig
from pftf import settings

# The tests from fancyconfig itself
fcTest = fancyconfig._getTestSuite()

class FontConfigTest(unittest.TestCase):
	"""tests for working FontConfigItem.
	"""
	def testParsing(self):
		ci = settings.FontConfigItem("foo", "Roman,8")
		self.assertEqual(ci.value, ("Roman", 8))
	
	def testNotParsing(self):
		ci = settings.FontConfigItem("foo", "Roman,8")
		self.assertRaises(settings.ParseError, ci.set, "Junk")
		self.assertRaises(settings.ParseError, ci.set, "Junk, Bunk")
		self.assertRaises(settings.ParseError, ci.set, "")


class DocMakingTest(unittest.TestCase):
	"""tests that some docs are spit out.
	"""
	def testDocProduction(self):
		self.assertEqual(fancyconfig.makeTxtDocs(settings._config)[:20],
			'\nSection [general]\n.')


class ConfigItemsValidTest(unittest.TestCase):
	"""tests for all defined config items beint accessible.
	"""
	def testAllConfigItems(self):
		for sect in settings._config:
			for item in sect:
				try:
					settings.get(sect.name, item.name)
				except:
					raise AssertionError("Bad config item: [%s]%s"%(
						sect.name, item.name))


if __name__=="__main__":
	import testhelpers
	testhelpers.main(DocMakingTest)
