"""
Helper classes for the unittest framework.
"""

import os
import popen2
import shutil
import sys
import tempfile
import unittest

os.environ["PFTFDATA"] = os.path.join(os.getcwd(), "pftftest")

from pftf import settings

class VerboseTest(unittest.TestCase):
	"""contains a few methods for improved error reporting.
	"""
	def assertEqualForArgs(self, callable, result, *args):
		self.assertEqual(callable(*args), result, 
			"Failed for arguments %s.  Expected result is: %s, result found"
			" was: %s"%(str(args), repr(result), repr(callable(*args))))

	def assertRaisesVerbose(self, exception, callable, args, msg):
		try:
			callable(*args)
		except exception:
			return
		except:
			raise
		else:
			raise self.failureException(msg)

	def assertRaisesWithMsg(self, exception, errMsg, callable, args, msg=None):
		try:
			callable(*args)
		except exception, ex:
			if str(ex)!=errMsg:
				raise self.failureException(
					"Expected %r, got %r as exception message"%(errMsg, str(ex)))
		except:
			raise
		else:
			raise self.failureException(msg or "%s not raised"%exception)


class CleanSlateTest(unittest.TestCase):
	"""is a base class for tests that want a clean data directory.

	IMPORTANT: You *must* have something like 
	os.environ["PFTFDATA"] = os.path.join(os.getcwd(), "pftftest")
	before importing settings when using such tests, or you must
	import testhelpers before any pftf module.  Failure to do so
	will nuke your data directory.
	"""
	def setUp(self):
		if not "PFTFDATA" in os.environ:
			raise Exception("Yikes -- no test dir set in tests")
		if os.path.isdir(settings.dataDir):
			shutil.rmtree(settings.dataDir)
		os.makedirs(settings.dataDir)

	def tearDown(self):
		shutil.rmtree(settings.dataDir)


def main(testClass, methodPrefix=None):
	if len(sys.argv)>1:
		suite = unittest.makeSuite(testClass, methodPrefix or sys.argv[1])
		runner = unittest.TextTestRunner()
		runner.run(suite)
	else:
		unittest.main()
